pub struct DiscoverableAuthenticationClientState<'rp_id, 'prf>(/* private fields */);Expand description
Container of a DiscoverableCredentialRequestOptions that has been used to start the authentication ceremony.
This gets sent to the client ASAP.
Implementations
Sourceimpl<'rp_id, 'prf> DiscoverableAuthenticationClientState<'rp_id, 'prf>
impl<'rp_id, 'prf> DiscoverableAuthenticationClientState<'rp_id, 'prf>
Sourcepub const fn options(
&self,
) -> &DiscoverableCredentialRequestOptions<'rp_id, 'prf>
pub const fn options( &self, ) -> &DiscoverableCredentialRequestOptions<'rp_id, 'prf>
Returns the DiscoverableCredentialRequestOptions that was used to start an authentication ceremony.